from django.core.exceptions import ImproperlyConfigured

try:
    from testrunner import DiscoverSlowestTestsRunner  # NOQA
except (ImportError, ImproperlyConfigured):
    pass

__version__ = "1.0.1"



import codecs

from os import path
from setuptools import find_packages, setup

from django_slowtests import __version__


def read(*parts):
    filename = path.join(path.dirname(__file__), *parts)
    with codecs.open(filename, encoding="utf-8") as fp:
        return fp.read()


setup(
    author="Michael Herman",
    author_email="michael@realpython.com",
    description="locate your slowest tests",
    name="django-slowtests",
    long_description=read("README.rst"),
    version=__version__,
    url="https://github.com/realpython/django-slow-tests",
    license="MIT",
    packages=find_packages(),
    tests_require=["Django>=1.6", "mock"],
    install_requires=["django>=1.6"],
    test_suite="runtests.runtests",
    classifiers=[
        "Environment :: Web Environment",
        "Framework :: Django",
        "Intended Audience :: Developers",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
        "Programming Language :: Python",
        "Programming Language :: Python :: 2.7",
        "Programming Language :: Python :: 3.3",
        "Programming Language :: Python :: 3.4",
        "Programming Language :: Python :: 3.5",
        "Programming Language :: Python :: 3.6",
        "Topic :: Internet :: WWW/HTTP",
        "Topic :: Internet :: WWW/HTTP :: Dynamic Content",
        "Topic :: Software Development :: Testing",
        "Topic :: Software Development :: Libraries :: Python Modules",
    ],
    zip_safe=False
)



import time
from django.test import TestCase
from freezegun import freeze_time


class FakeTestCase(TestCase):
    _setupClassRan = False

    @classmethod
    def setUpClass(cls):
        super(FakeTestCase, cls).setUpClass()
        cls._setupClassRan = True

    def test_slow_thing(self):
        time.sleep(1)

    def test_setup_class_was_run(self):
        self.assertTrue(self._setupClassRan)


@freeze_time('2016-02-03 12:34:56')
class FakeFrozenInPastTestCase(TestCase):

    def test_this_should_not_have_a_negative_duration(self):
        self.assertTrue(True)


@freeze_time('3017-02-03 12:34:56')
class FakeFrozenInFutureTestCase(TestCase):

    def test_this_should_not_have_very_long_duration(self):
        self.assertTrue(True)
